@@ -55,9 +55,9 @@
 #define ANZWARN		13
 
 #define programname	"xa"
-#define progversion	"v2.3.5"
+#define progversion	"v2.3.7"
 #define authors		"Written by Andre Fachat, Jolse Maginnis, David Weinehall and Cameron Kaiser"
-#define copyright	"Copyright (C) 1989-2009 Andre Fachat, Jolse Maginnis, David Weinehall\nand Cameron Kaiser."
+#define copyright	"Copyright (C) 1989-2015 Andre Fachat, Jolse Maginnis, David Weinehall\nand Cameron Kaiser."
 
 /* exported globals */
 int ncmos, cmosfl, w65816, n65816;
@@ -87,7 +87,7 @@ static int pass2(void);
 static int puttmp(int);
 static int puttmps(signed char *, int);
 static void chrput(int);
-static int getline(char *);
+static int xa_getline(char *);
 static void lineout(void);
 static long ga_p1(void);
 static long gm_p1(void);
@@ -355,6 +355,7 @@ int main(int argc,char *argv[])
 	if(setfext(old_o,".obj")==0) ofile = old_o;
 	if(setfext(old_l,".lab")==0) lfile = old_l;
      }
+     if(verbose) fprintf(stderr, "%s\n",copyright);
 
      fplab= lfile ? xfopen(lfile,"w") : NULL;
      fperr= efile ? xfopen(efile,"w") : NULL;
@@ -369,8 +370,6 @@ int main(int argc,char *argv[])
 	exit(1);
      }
 
-     if(verbose) fprintf(stderr, "%s\n",copyright);
-
      if(1 /*!m_init()*/)
      {
        if(1 /*!b_init()*/)
@@ -381,7 +380,7 @@ int main(int argc,char *argv[])
            {
              if(!x_init())
              {
-	       if(fperr) fprintf(fperr,"%s\n",copyright);
+	       /* if(fperr) fprintf(fperr,"%s\n",copyright); */
 	       if(verbose) logout(ctime(&tim1));
 
 	       /* Pass 1 */
@@ -763,7 +762,7 @@ static int pass1(void)
 	temp_er = 0;
 
 /*FIXIT*/
-     while(!(er=getline(s)))
+     while(!(er=xa_getline(s)))
      {         
           er=t_p1((signed char*)s,o,&l,&al);
 	  switch(segment) {
@@ -804,7 +803,6 @@ static int pass1(void)
      } 
 
      if(er!=E_EOF) {
-	fprintf(stderr, "foul through\n");
           errout(er);
 	}
 
@@ -898,7 +896,7 @@ static char *ertxt[] = {
 	"DSB",
 	"NewLine",
         "NewFile",
-	"CMOS-Befehl",
+	"CMOS instruction used with -C",
 	"pp:Wrong parameter count",
 	"Illegal pointer arithmetic", 
 	"Illegal segment",
@@ -951,10 +949,10 @@ static char *ertxt[] = {
 	  "Open preprocessor directive at end of file (intentional?)",
 	  "Included binary data exceeds 64KB",
 	  "Included binary data exceeds 16MB",
+          "MVN/MVP $XXXX syntax is deprecated and will be removed",
 /* more placeholders */
 		"",
 		"",
-		"",
 
  };
 
@@ -1002,7 +1000,7 @@ static int puttmps(signed char *s, int l)
 
 static char l[MAXLINE];
 
-static int getline(char *s)
+static int xa_getline(char *s)
 {
      static int ec;
 
